@@ -86,8 +86,8 @@ class BivariateNSEmpirical(BaseCapacityModel):
     ):
         """
         Args:
-            demand_data (np.ndarray): Demand data matrix with two columns
-            renewables_data (np.ndarray): Renewable generation data matrix with two columns
+            demand_data (np.ndarray): Demand data array with two columns
+            renewables_data (np.ndarray): Renewable generation data array with two columns
             gen_distributions (t.List[acg_models.NonSequential]): List of non-sequential ACG objects
             season_length (int, optional): length of peak season. If None, it is set as the length of demand data
 
@@ -261,13 +261,17 @@ class BivariateNSEmpirical(BaseCapacityModel):
             x=self.gen_distribution.y, y=self.gen_distribution.x
         )
 
-    def eeu(self, itc_cap: int = 1000, policy: str = "veto", area: int = 0):
-        """Computes the post-interconnection expected energy unserved.
+    def eeu(self, itc_cap: int = 1000, policy: str = "veto", area: int = 0) -> float:
+        """Computes the post-interconnection expected energy unserved (EEU).
 
         Args:
             itc_cap (int, optional): interconnection capacity
             policy (str, optional): one of 'veto' or 'share'; in a 'veto' policy, areas only export spare available capacity, while in a 'share' policy, capacity shortfalls are shared according to demand proportions across areas. Shortfalls can extend from one area to another by diverting power.
             area (int, optional): Area for which to evaluate eeu; if area=-1, systemwide eeu is returned
+
+        Returns:
+            float: Estimated EEU
+
         """
 
         if area == -1:
@@ -568,8 +572,8 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
 
     Args:
         gen_dir (str): folder with conventional generation data
-        demand (np.ndarray): demand data
-        renewables (np.ndarray): renewables data
+        demand (np.ndarray): one-dimensionsl demand data
+        renewables (np.ndarray): one-dimensional renewables data
         season_length (int): number of timesteps per peak season
         n_cores (int, optional): number of cores to use for map-reduce operations
 
@@ -583,6 +587,11 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
 
     _worker_class = UnivariateTraces
 
+    @validator("demand", "renewables", allow_reuse=True)
+    def check_shape_and_order(cls, data):
+        # ensures passed arrays are one-dimensional and follow row-major order
+        return np.ascontiguousarray(data, np.float32).reshape(-1)
+
     class Config:
         arbitrary_types_allowed = True
 
@@ -617,7 +626,7 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
         seed: int = None,
         compress_files: bool = False,
     ) -> UnivariateSequential:
-        """Generate and persists traces of conventional generation in files, and uses them to instantiate a surplus model. Returns a surplus model ready to perform computations with the generated files.
+        """Generate and persists traces of conventional generation in multiple files, and uses them to instantiate a capacity surplus model. Returns a surplus model ready to perform computations on the generated files.
 
         Args:
             output_dir (str): Output directory for trace files
@@ -802,11 +811,11 @@ class UnivariateSequential(BaseCapacityModel, BasePydanticModel):
             x=-1e-1
         )  # tiny offset to avoid issues with numerical rounding errors from adding millions of numbers together
 
-    def eeu(self):
-        """Computes the expected energy unserved
+    def eeu(self) -> float:
+        """Computes the expected energy unserved (EEU)
 
         Returns:
-            float: eeu estimate
+            float: estimated EEU
         """
 
         def reducer(mapped):
@@ -883,8 +892,8 @@ class BivariateSequential(UnivariateSequential):
 
     Args:
         gen_dir (str): folder with conventional generation data
-        demand (np.ndarray): demand data
-        renewables (np.ndarray): renewables data
+        demand (np.ndarray): two-dimensional demand array with two columns
+        renewables (np.ndarray): two-dimensional renewables data array with two columns
         season_length (int): number of timesteps per peak season
         n_cores (int, optional): number of cores to use for map-reduce operations
     """
@@ -892,6 +901,15 @@ class BivariateSequential(UnivariateSequential):
     _worker_class = BivariateTraces
     _area_indices = [0, 1]
 
+    @validator("demand", "renewables", allow_reuse=True)
+    def check_shape_and_order(cls, data):
+        # ensures passed arrays are twi-dimensional and follow row-major order
+        if len(data.shape) != 2 or data.shape[1] != 2:
+            raise ValueError(
+                "passed data arrays must be two-dimensional with two columns"
+            )
+        return np.ascontiguousarray(data, np.float32)
+
     @property
     def filedirs(self):
         return [Path(self.gen_dir) / str(area) for area in self._area_indices]
@@ -910,7 +928,7 @@ class BivariateSequential(UnivariateSequential):
         burn_in: int = 100,
         compress_files: bool = False,
     ) -> BivariateSequential:
-        """Generate and persists traces of conventional generation in files, and use them to instantiate a surplus model.
+        """Generate and persists traces of conventional generation in multiple files, and uses them to instantiate a capacity surplus model. Returns a model ready to perform computations on the generated files.
 
         Args:
             output_dir (str): output directory for trace files
@@ -933,7 +951,6 @@ class BivariateSequential(UnivariateSequential):
             cls._area_indices, gens, demand.T, renewables.T
         ):
             out_dir = Path(output_dir) / str(area)
-            print(f"Creating files for area {area}..")
             UnivariateSequential.init(
                 output_dir=str(out_dir),
                 n_traces=n_traces,
@@ -1063,13 +1080,17 @@ class BivariateSequential(UnivariateSequential):
             str_map_kwargs={"x": x},
         )
 
-    def lole(self, itc_cap: float = 1000.0, policy="veto", area: int = 0):
-        """Computes the post-interconnection loss of load expectation.
+    def lole(self, itc_cap: float = 1000.0, policy="veto", area: int = 0) -> float:
+        """Computes the post-interconnection loss of load expectation (LOLE)
 
         Args:
-            itc_cap (int, optional): interconnection capacity
+            itc_cap (float, optional): interconnection capacity
             policy (str, optional): one of 'veto' or 'share'; in a 'veto' policy, areas only export spare available capacity, while in a 'share' policy, exports are market-driven, i.e., by power scarcity at both areas. Shortfalls can extend from one area to another by diverting power.
             area (int, optional): Area for which to evaluate LOLE; if area=-1, system-wide lole is returned
+
+        Returns:
+            float: estimated LOLE
+
         """
         offset = (
             -1e-1
@@ -1089,13 +1110,16 @@ class BivariateSequential(UnivariateSequential):
         else:
             raise ValueError("area must be in [-1,0,1]")
 
-    def eeu(self, itc_cap: float = 1000.0, policy="veto", area: int = 0):
-        """Computes the post-interconnection expected energy unserved.
+    def eeu(self, itc_cap: float = 1000.0, policy="veto", area: int = 0) -> float:
+        """Computes the post-interconnection expected energy unserved (EEU)
 
         Args:
-            itc_cap (int, optional): interconnection capacity
+            itc_cap (float, optional): interconnection capacity
             policy (str, optional): one of 'veto' or 'share'; in a 'veto' policy, areas only export spare available capacity, while in a 'share' policy, exports are market-driven, i.e., by power scarcity at both areas. Shortfalls can extend from one area to another by diverting power.
             area (int, optional): Area for which to evaluate eeu; if area=-1, systemwide eeu is returned
+
+        Returns:
+            float: estimated EEU
         """
 
         def reducer(mapped):
