@@ -1588,7 +1588,7 @@ class Empirical(BaseDistribution):
             q (t.Union[float, np.ndarray]): probability level
 
         Returns:
-            t.Union[float, np.ndarray]: Linearly interpolated quantile function
+            t.Union[float, np.ndarray]: Evaluations of the (Linearly interpolated) quantile function
 
         """
         is_scalar = isinstance(q, self._allowed_scalar_types)
@@ -1637,7 +1637,9 @@ class Empirical(BaseDistribution):
 
     @classmethod
     def from_data(cls, data: np.array):
-
+        if len(data.shape) != 1:
+            warnings.warn("Reshaping input data to one-dimensional array")
+        data = np.ascontiguousarray(data, data.dtype).reshape(-1)
         support, unnorm_pdf = np.unique(data, return_counts=True)
         n = np.sum(unnorm_pdf)
         return cls(support=support, pdf_values=unnorm_pdf / n, data=data)
@@ -1713,7 +1715,7 @@ class Empirical(BaseDistribution):
         """Returns the distribution resulting from an arbitrary transformation
 
         Args:
-            f (t.Callable): Target transformation; it should take a numpy array as input
+            f (t.Callable): function to apply; it should take a numpy array as input
 
         """
         dist_df = pd.DataFrame({"pdf": self.pdf_values, "support": f(self.support)})
